---------------------------------------------------------------------------------
--
-- SCENE2.LUA
--
---------------------------------------------------------------------------------

local Storyboard = require( "storyboard" )
local Scene      = Storyboard.newScene()
local BG

----------------------------------------------------------------
-- CREATE THE SCENE (WHEN THE SCENE'S VIEW DOES NOT EXIST)
----------------------------------------------------------------
function Scene:createScene( event )
	local Screen = self.view
	
	-- BG IMAGE
	BG       = display.newImage("bg_scene2.png")
	BG.x     = display.contentWidth  *.5
	BG.y     = display.contentHeight *.5
	BG.alpha = 0.2
	Screen:insert(BG)

	-- TO REMEMBER RADIO BUTTON SETTING
	if _G.selectedOption == nil then _G.selectedOption = 1 end

	-- CREATE YOUR WIDGETS HERE
	for i = 1, 4 do
		_G.GUI.NewRadiobutton(
			{
			x               = "center",                
			y               = display.contentHeight *.2 + (i*30)*_G.GUIScale, 
			width           = "50%",
			scale           = _G.GUIScale,
			name            = "RAD_"..i,            
			parentGroup     = Screen,                     
			theme           = "theme_5", 
			caption         = "This is radio button number "..i,
			textAlign       = "right",
			textColor       = {255,255,255},
			toggleState     = i == _G.selectedOption and true or false,
			toggleGroup     = "RadioGroup1",
			myNumber        = i, -- YOU CAN ADD CUSTOM PROPERTIES AS WELL
			group           = "MyGroup1",
			
			onPress         = function(EventData) 
								-- REMEMBER RADIO BUTTON SETTING
								if EventData.toggleState == true then 
									_G.selectedOption = EventData.Props.myNumber
								end
							  end,
			} )
	end

	_G.GUI.NewBorder(
		{
		name              = "BORDER",
		parentGroup       = Screen,
		name              = "BORDER",
		theme             = "theme_5",
		group             = "MyGroup1",
		border            = {"inset",4,1, 200,200,200,150}, 
		zindex            = 1, -- DRAW BEHIND OTHER WIDGETS
		} )

	_G.GUI.NewButton(
		{
		x               = "center",  
		y               = "bottom",
		width           = "auto", 
		scale           = _G.GUIScale,
		name            = "BUT_SCENE2",            
		parentGroup     = Screen,                     
		theme           = "theme_5",               
		caption         = "Next (Scene 3)", 
		textAlign       = "center",                  
		icon            = 7,        
		onRelease       = function(EventData)
							Storyboard.gotoScene( "scene3", "slideLeft", 800  )
						  end,
		} )
end


----------------------------------------------------------------
-- CALLED IMMEDIATELY AFTER SCENE HAS MOVED ONSCREEN:
----------------------------------------------------------------
function Scene:enterScene( event )

	print( "ENTERED SCENE 2" )
	
	-- REMOVE PREVIOUS SCENE'S VIEW
	Storyboard.purgeScene( "scene1" )
	
end


----------------------------------------------------------------
-- CALLED WHEN SCENE IS ABOUT TO MOVE OFFSCREEN:
----------------------------------------------------------------
function Scene:exitScene( event )
	print( "EXIT SCENE 2" )
end


----------------------------------------------------------------
-- CALLED PRIOR TO THE REMOVAL OF SCENE'S "VIEW" (DISPLAY GROUP)
----------------------------------------------------------------
function Scene:destroyScene( event )
	print( "DESTROYING SCENE 2" )
	
	-- REMOVE BG IMAGE
	BG:removeSelf()

	-- REMOVE ALL WIDGETS HERE
	_G.GUI.GetHandle("BUT_SCENE2"):destroy()
	_G.GUI.GetHandle("BORDER"    ):destroy()
	for i = 1, 4 do _G.GUI.GetHandle("RAD_"..i):destroy() end
end

---------------------------------------------------------------------------------
-- END OF YOUR IMPLEMENTATION
---------------------------------------------------------------------------------

-- "CREATESCENE" EVENT IS DISPATCHED IF SCENE'S VIEW DOES NOT EXIST
Scene:addEventListener( "createScene", Scene )

-- "ENTERSCENE" EVENT IS DISPATCHED WHENEVER SCENE TRANSITION HAS FINISHED
Scene:addEventListener( "enterScene", Scene )

-- "EXITSCENE" EVENT IS DISPATCHED BEFORE NEXT SCENE'S TRANSITION BEGINS
Scene:addEventListener( "exitScene", Scene )

-- "DESTROYSCENE" EVENT IS DISPATCHED BEFORE VIEW IS UNLOADED, WHICH CAN BE
-- AUTOMATICALLY UNLOADED IN LOW MEMORY SITUATIONS, OR EXPLICITLY VIA A CALL TO
-- STORYBOARD.PURGESCENE() OR STORYBOARD.REMOVESCENE().
Scene:addEventListener( "destroyScene", Scene )

---------------------------------------------------------------------------------

return Scene