---------------------------------------------------------------------------------
--
-- SCENE3.LUA
--
---------------------------------------------------------------------------------

local Storyboard = require( "storyboard" )
local Scene      = Storyboard.newScene()
local BG

----------------------------------------------------------------
-- CREATE THE SCENE (WHEN THE SCENE'S VIEW DOES NOT EXIST)
----------------------------------------------------------------
function Scene:createScene( event )
	local Screen = self.view
	
	-- BG IMAGE
	BG       = display.newImage("bg_scene3.png")
	BG.x     = display.contentWidth  *.5
	BG.y     = display.contentHeight *.5
	BG.alpha = 0.2
	Screen:insert(BG)

	-- CREATE YOUR WIDGETS HERE
	_G.GUI.NewText(
		{
		x               = "center",                
		y               = "center", 
		width           = "50%",
		scale           = _G.GUIScale,
		height          = "auto",
		name            = "TXT_SCENE3",            
		parentGroup     = Screen,                     
		theme           = "theme_5", 
		caption         = "This is scene 3. Tap the button below to return to scene 1.",
		textColor       = {255,255,255},
		textAlign       = "center",
		border          = {"normal",4,1, 150,150,250,150, 255,255,255,200},
		} )

	_G.GUI.NewButton(
		{
		x               = "center",  
		y               = "bottom",
		width           = "auto", 
		scale           = _G.GUIScale,
		name            = "BUT_SCENE3",            
		parentGroup     = Screen,                     
		theme           = "theme_5",               
		caption         = "Return to Scene 1", 
		textAlign       = "center",                  
		icon            = 7,        
		onRelease       = function(EventData)
							Storyboard.gotoScene( "scene1", "slideLeft", 800  )
						  end,
		} )
end


----------------------------------------------------------------
-- CALLED IMMEDIATELY AFTER SCENE HAS MOVED ONSCREEN:
----------------------------------------------------------------
function Scene:enterScene( event )

	print( "ENTERED SCENE 3" )
	
	-- REMOVE PREVIOUS SCENE'S VIEW
	Storyboard.purgeScene( "scene2" )
	
end


----------------------------------------------------------------
-- CALLED WHEN SCENE IS ABOUT TO MOVE OFFSCREEN:
----------------------------------------------------------------
function Scene:exitScene( event )
	print( "EXIT SCENE 3" )
end


----------------------------------------------------------------
-- CALLED PRIOR TO THE REMOVAL OF SCENE'S "VIEW" (DISPLAY GROUP)
----------------------------------------------------------------
function Scene:destroyScene( event )
	print( "DESTROYING SCENE 3" )
	
	-- REMOVE BG IMAGE
	BG:removeSelf()

	-- REMOVE ALL WIDGETS HERE
	_G.GUI.GetHandle("TXT_SCENE3"):destroy()
	_G.GUI.GetHandle("BUT_SCENE3"):destroy()
end

---------------------------------------------------------------------------------
-- END OF YOUR IMPLEMENTATION
---------------------------------------------------------------------------------

-- "CREATESCENE" EVENT IS DISPATCHED IF SCENE'S VIEW DOES NOT EXIST
Scene:addEventListener( "createScene", Scene )

-- "ENTERSCENE" EVENT IS DISPATCHED WHENEVER SCENE TRANSITION HAS FINISHED
Scene:addEventListener( "enterScene", Scene )

-- "EXITSCENE" EVENT IS DISPATCHED BEFORE NEXT SCENE'S TRANSITION BEGINS
Scene:addEventListener( "exitScene", Scene )

-- "DESTROYSCENE" EVENT IS DISPATCHED BEFORE VIEW IS UNLOADED, WHICH CAN BE
-- AUTOMATICALLY UNLOADED IN LOW MEMORY SITUATIONS, OR EXPLICITLY VIA A CALL TO
-- STORYBOARD.PURGESCENE() OR STORYBOARD.REMOVESCENE().
Scene:addEventListener( "destroyScene", Scene )

---------------------------------------------------------------------------------

return Scene